@@ -1,4 +1,3 @@
-import logging
 import secrets
 import string
 from dataclasses import dataclass
@@ -10,6 +9,7 @@ from appdirs import user_config_dir, user_data_dir
 from email_validator import EmailSyntaxError
 
 from lime_comb.logger.logger import logger
+from lime_comb.validators.bool import validate_bool
 from lime_comb.validators.email import lc_validate_email
 
 
@@ -173,7 +173,8 @@ class Config:
         )
         print("-" * 44)
 
-    def get_bool(self, message, *, default=None):
+    @classmethod
+    def get_bool(cls, message, *, default=None):
         while True:
             my_bool = input(f"{message} [True/False]: ")
             if my_bool == "" and default != None:
@@ -194,13 +195,6 @@ def convert_bool_string(my_bool):
     return False
 
 
-def validate_bool(my_bool):
-    if isinstance(my_bool, bool):
-        return True
-    if my_bool.lower() not in ("true", "false"):
-        raise ValueError
-
-
 class EmptyConfigError(Exception):
     pass
 
